@@ -3,6 +3,8 @@
  *
  * Copyright (C) 2003, 2004 Red Hat, Inc.
  *
+ * SPDX-License-Identifier: AFL-2.1 OR GPL-2.0-or-later
+ *
  * Licensed under the Academic Free License version 2.1
  *
  * This program is free software; you can redistribute it and/or modify
@@ -29,7 +31,6 @@
 
 #include "activation.h"
 #include "connection.h"
-#include "containers.h"
 #include "dispatch.h"
 #include "services.h"
 #include "utils.h"
@@ -71,7 +72,6 @@ struct BusContext
   BusMatchmaker *matchmaker;
   BusLimits limits;
   DBusRLimit *initial_fd_limit;
-  BusContainers *containers;
   unsigned int fork : 1;
   unsigned int syslog : 1;
   unsigned int keep_umask : 1;
@@ -919,14 +919,6 @@ bus_context_new (const DBusString *config_file,
       goto failed;
     }
 
-  context->containers = bus_containers_new ();
-
-  if (context->containers == NULL)
-    {
-      BUS_SET_OOM (error);
-      goto failed;
-    }
-
   /* check user before we fork */
   if (context->user != NULL)
     {
@@ -1227,9 +1219,6 @@ bus_context_shutdown (BusContext  *context)
 
       link = _dbus_list_get_next_link (&context->servers, link);
     }
-
-  if (context->containers != NULL)
-    bus_containers_stop_listening (context->containers);
 }
 
 BusContext *
@@ -1300,7 +1289,6 @@ bus_context_unref (BusContext *context)
           context->matchmaker = NULL;
         }
 
-      bus_clear_containers (&context->containers);
       dbus_free (context->config_file);
       dbus_free (context->log_prefix);
       dbus_free (context->type);
@@ -1405,12 +1393,6 @@ bus_context_allow_windows_user (BusContext       *context,
                                         windows_sid);
 }
 
-BusContainers *
-bus_context_get_containers (BusContext *context)
-{
-  return context->containers;
-}
-
 BusClientPolicy*
 bus_context_create_client_policy (BusContext      *context,
                                   DBusConnection  *connection,
